PlatformIO

Struct PlatformIO 

pub struct PlatformIO { /* private fields */ }
UnixIO lives longer than any of the files it creates, so it is safe to store references to it’s internals in the UnixFiles

Implementations

Source

impl UnixIO

pub fn new() -> Result<Self>