pub struct Statement { /* private fields */ }Implementations
Sourceimpl Statement
impl Statement
pub fn new( program: Rc<Program>, mv_store: Option<Rc<MvStore<LocalClock>>>, pager: Rc<Pager>, ) -> Self
pub fn set_mv_tx_id(&mut self, mv_tx_id: Option<u64>)
pub fn interrupt(&mut self)
pub fn step(&mut self) -> Result<StepResult>
pub fn run_once(&self) -> Result<()>
pub fn num_columns(&self) -> usize
pub fn get_column_name(&self, idx: usize) -> Cow<'_, str>
Sourcepub fn get_column_decl_type(&self, idx: usize) -> Option<Cow<'_, str>>
pub fn get_column_decl_type(&self, idx: usize) -> Option<Cow<'_, str>>
Return the declared SQL type string for result column idx, if available.
The declared type is the text written after the column name in CREATE TABLE
(e.g. "DATE", "TIMESTAMP", "UUID", "INTEGER", …). For computed
expressions or columns from sub-selects the method returns None.
pub fn parameters(&self) -> &Parameters
pub fn parameters_count(&self) -> usize
pub fn bind_at(&mut self, index: NonZero<usize>, value: Value)
pub fn reset(&mut self)
pub fn row(&self) -> Option<&Row>
pub fn explain(&self) -> String